@@ -166,9 +166,9 @@ bool cLogoDetect::LoadLogoPlane(const char *path, const char *logoName, const in
     FILE *pFile = nullptr;
     pFile = fopen(logoFileName, "rb");
     FREE(strlen(logoFileName) + 1, "logoFileName");
-    free(logoFileName);
     if (!pFile) {
         dsyslog("cLogoDetect::LoadLogoPlane(): file not found for logo %s plane %d in %s", logoName, plane, path);
+        free(logoFileName);
         return false;
     }
     dsyslog("cLogoDetect::LoadLogoPlane(): file found for logo %s plane %d in %s", logoName, plane, path);
@@ -178,9 +178,11 @@ bool cLogoDetect::LoadLogoPlane(const char *path, const char *logoName, const in
     char c;
     if (fscanf(pFile, "P5\n#%1c%1i %4i\n%3d %3d\n255\n#", &c, &area.logoCorner, &area.mPixel[plane], &width, &height) != 5) {
         fclose(pFile);
-        esyslog("format error in %s", logoFileName);
+        esyslog("logo file format error in %s", logoFileName);
+        free(logoFileName);
         return false;
     }
+    free(logoFileName);
 
     if (height == 255) {
         height = width;
@@ -380,10 +382,17 @@ bool cLogoDetect::ReduceBrightness(const int logo_vmark, int *logo_imark) {
                 ((contrastLogo  >   3) && (contrastLogo <=  10) && (brightnessLogo > 202)) ||
                 // (+) contrast  41, brightness 199, logo on bright sky background
                 ((contrastLogo  >  10) && (contrastLogo <=  41) && (brightnessLogo > 199)) ||
-                ((contrastLogo  >  41) && (contrastLogo <= 130) && (brightnessLogo > 180)) ||
-                ((contrastLogo  > 130) && (contrastLogo <= 150) && (brightnessLogo > 150)) ||
-                ((contrastLogo  > 150) && (contrastLogo <= 180) && (brightnessLogo > 140)) ||
-                ((contrastLogo  > 180) && (contrastLogo <= 200) && (brightnessLogo > 124)) ||
+                ((contrastLogo  >  41) && (contrastLogo <= 120) && (brightnessLogo > 180)) ||
+                // (-) logo area before reduction: contrast 130, brightness 133
+                // (-) logo area before reduction: contrast 130, brightness 130
+                // (-) logo area before reduction: contrast 131, brightness 131
+                // (-) logo area before reduction: contrast 131, brightness 127
+                // (-) logo area before reduction: contrast 131, brightness 126
+                // (-) logo area before reduction: contrast 139, brightness 132
+                // (-) logo area before reduction: contrast 141, brightness 129
+                ((contrastLogo  > 120) && (contrastLogo <= 180) && (brightnessLogo > 125)) ||
+                // (-) logo area before reduction: contrast 184, brightness 114
+                ((contrastLogo  > 180) && (contrastLogo <= 200) && (brightnessLogo > 113)) ||
                 ((contrastLogo  > 200) &&                          (brightnessLogo > 104))) {
 #ifdef DEBUG_LOGO_DETECTION
             dsyslog("cLogoDetect::ReduceBrightness(): frame (%6d): logo invisible, contrast/brightness in logo area is invalid for brightness reduction", decoder->GetPacketNumber());
@@ -398,7 +407,8 @@ bool cLogoDetect::ReduceBrightness(const int logo_vmark, int *logo_imark) {
                 // (-) contrast   1, brightness 206   -> logo on bright sky
                 ((contrastLogo  >   0) && (contrastLogo <=   3) && (brightnessLogo > 205)) ||
                 ((contrastLogo  >   3) && (contrastLogo <=  10) && (brightnessLogo > 202)) ||
-                ((contrastLogo  >  10) && (contrastLogo <=  20) && (brightnessLogo > 197)) ||
+                // (-) contrast  20, brightness 196   -> logo on bright sky
+                ((contrastLogo  >  10) && (contrastLogo <=  20) && (brightnessLogo > 195)) ||
                 // (-) contrast  31, brightness 187   -> logo on bright sky
                 ((contrastLogo  >  20) && (contrastLogo <=  35) && (brightnessLogo > 186)) ||
                 ((contrastLogo  >  35) && (contrastLogo <= 130) && (brightnessLogo > 180)) ||
@@ -1399,6 +1409,7 @@ int cHorizBorderDetect::Process(int *hBorderPacketNumber, int64_t *hBorderFrameP
     if (!hBorderFramePTS)     return HBORDER_ERROR;
 #define CHECKHEIGHT           5  // changed from 8 to 5
 #define NO_HBORDER          200  // internal limit for early loop exit, must be more than BRIGHTNESS_H_MAYBE
+#define IGNORE_EDGE         0.2  // ignore 20% of left and right edge in case of we have vborder
 
     const sVideoPicture *picture = decoder->GetVideoPicture();
     if (!picture) {  // picture->pts, picture->plane[] and picture->planeLineSize[] was checked by GetVideoPicture()
@@ -1414,25 +1425,25 @@ int cHorizBorderDetect::Process(int *hBorderPacketNumber, int64_t *hBorderFrameP
     int valBottom        =  0;
 
     // check top border
-    for (int line = 1; line < CHECKHEIGHT ; line++) {  // ignore first line, sometimes the are pixel
-        for (int column = 0; column < picture->width; column++) {
+    for (int line = 1; line < CHECKHEIGHT ; line++) {  // ignore first line, sometimes there are pixel
+        for (int column = picture->width * IGNORE_EDGE; column < picture->width * (1 - IGNORE_EDGE); column++) {  // ignore left and right edge in case of we have vborder
             sumTop += picture->plane[0][(line * picture->planeLineSize[0] + column)];
         }
-        valTop = sumTop / ((CHECKHEIGHT - 1) * picture->width);
+        valTop = sumTop / ((CHECKHEIGHT - 1) * picture->width * (1 - IGNORE_EDGE) * (1 - IGNORE_EDGE));
         if (valTop > brightnessMaybe) break;
     }
-    valTop = sumTop / ((CHECKHEIGHT - 1) * picture->width);
+    valTop = sumTop / ((CHECKHEIGHT - 1) * picture->width * (1 - IGNORE_EDGE) * (1 - IGNORE_EDGE));
 
     // check bottom border
     if (valTop <= brightnessMaybe) {
         for (int line = picture->height - CHECKHEIGHT; line < picture->height; line++) {
-            for (int column = 0; column < picture->width; column++) {
+            for (int column =  picture->width * IGNORE_EDGE; column < picture->width * (1 - IGNORE_EDGE); column++) {  // ignore left and right edge in case of we have vborder
                 sumBottom += picture->plane[0][(line * picture->planeLineSize[0] + column)];
             }
-            valBottom = sumBottom / (CHECKHEIGHT * picture->width);
+            valBottom = sumBottom / (CHECKHEIGHT * picture->width * (1 - IGNORE_EDGE) * (1 - IGNORE_EDGE));
             if (valBottom > brightnessMaybe) break;
         }
-        valBottom = sumBottom / (CHECKHEIGHT * picture->width);
+        valBottom = sumBottom / (CHECKHEIGHT * picture->width * (1 - IGNORE_EDGE) * (1 - IGNORE_EDGE));
     }
     else valBottom = NO_HBORDER;   // we have no top border, so we do not have to calculate bottom border
 
@@ -1444,7 +1455,7 @@ int cHorizBorderDetect::Process(int *hBorderPacketNumber, int64_t *hBorderFrameP
         // check if we have hborder in bright picture
         if (!valid) {
             int pictureBrightness = GetPictureCenterBrightness(picture);
-            if (pictureBrightness > 44) {
+            if (pictureBrightness > 55) { // changed from 44 to 55
 #ifdef DEBUG_HBORDER
                 dsyslog("cHorizBorderDetect::Process(): packet (%7d): first hborder in bright %d picture", picture->packetNumber, pictureBrightness);
 #endif
